% -*- coding: utf-8; -*-
% 
% ------------------------------------------------------------
% Copyright 2018 by Paul Gaborit
% 
% This file may be distributed and/or modified
% 
% 1. under the LaTeX Project Public License and/or
% 2. under the GNU Public License.
% 
% See the file mines-albi-poster/LICENSE for more details.
% ------------------------------------------------------------
\RequirePackage{etex}
\NeedsTeXFormat{LaTeX2e}
\def\mapo@version{v0.2}
\def\mapo@date{2022/03/07}
\ProvidesClass{mines-albi-poster}[\mapo@date\space\mapo@version\space Mines Albi Poster class]

% Pour définir des commandes facilement
% \RequirePackage[log-declarations=false]{xparse}
\RequirePackage{xparse}

% Pour les warnings et les erreurs
\NewDocumentCommand\mapo@error{m m}{\ClassError{mines-albi-poster}{#1}{#2}}
\NewDocumentCommand\mapo@warning{m}{\ClassWarning{mines-albi-poster}{#1}}

% ------------------------------------------------------------
% les options
% ------------------------------------------------------------
% pour gérer les options
\RequirePackage{etoolbox}
\RequirePackage{pgfopts}
\RequirePackage{pgffor}
% pour des calculs
\RequirePackage{xfp}

% une commande pour se placer dans notre espace de noms
\NewExpandableDocumentCommand\mapo@keys@prefix{}{/mapo}
\NewDocumentCommand\mapo@keys{m}{\pgfqkeys{\mapo@keys@prefix}{#1}}

% choix des langues
\mapo@keys{
  languages/.store in=\mapo@languages,
  main-language/.store in=\mapo@mainlanguage,
  % initial values
  languages={english,french},
  main-language=french,
}

% famille de polices
\mapo@keys{
  font-family@load-lmodern/.code={
    \RequirePackage{lmodern}
    \AtBeginDocument{
      \DeclareFontShape{OMX}{cmex}{m}{n}{
        <-7.5> cmex7
        <7.5-8.5> cmex8
        <8.5-9.5> cmex9
        <9.5-> cmex10
      }{}
      \SetSymbolFont{largesymbols}{normal}{OMX}{cmex}{m}{n}
      \SetSymbolFont{largesymbols}{bold}  {OMX}{cmex}{m}{n}
    }
  },
  font-family/.is choice,
  % all choices
  font-family/lmodern/.style={font-family@load-lmodern},
  font-family/kpfonts/.style={font-family@apply/.code={
      \RequirePackage{kpfonts}
    }},
  font-family/mathptmx/.style={font-family@apply/.code={
      \RequirePackage{mathptmx}
    }},
  font-family/source/.style={
    font-family@load-lmodern, font-family@apply/.code={
      \RequirePackage[ttdefault,black,scale=.95]{sourcecodepro}
      \RequirePackage[sfdefault,default,black,scale=.95]{sourcesanspro}
      \RequirePackage[rmdefault,black,scale=.95]{sourceserifpro}
    }},
  font-family/newtx/.style={font-family@apply/.code={
      \RequirePackage[scaled=1,helvratio=.9]{newtxtext}
      \RequirePackage{newtxmath}
    }},
  font-family/newpx/.style={font-family@apply/.code={
      \RequirePackage{newpxtext}
      \RequirePackage{newpxmath}
    }},
  font-family/bera/.style={font-family@apply/.code={
      \RequirePackage{bera}
    }},
  font-family/libertinus/.style={
    font-family@load-lmodern, font-family@apply/.code={
      \RequirePackage{libertinus}
    }},
  % initial values
  font-family=lmodern,
}

% pour la taille du papier
\newif\ifmapo@landscape
\mapo@keys{
  % 
  paper-name/.store in=\mapo@paper,
  base-size/.code={\edef\mapo@basesize{\fpeval{#1}}},
  % 
  paper/.is choice,
  paper/a0/.style={paper-name=a0paper,base-size=40},
  paper/a1/.style={paper-name=a1paper,base-size={\fpeval{40/sqrt(2)}}},
  paper/a2/.style={paper-name=a2paper,base-size={\fpeval{40/(sqrt(2)^2)}}},
  paper/a3/.style={paper-name=a3paper,base-size={\fpeval{40/(sqrt(2)^3)}}},
  paper/a4/.style={paper-name=a4paper,base-size={\fpeval{40/(sqrt(2)^4)}}},
  % 
  a0paper/.style={paper=a0},
  a1paper/.style={paper=a1},
  a2paper/.style={paper=a2},
  a3paper/.style={paper=a3},
  a4paper/.style={paper=a4},
  % 
  landscape/.is if=mapo@landscape,
  % initial values
  paper=a0,
  landscape=false,
}

% pour les dépassements dans les marges
\newbool{mat@showoverfull}
\mapo@keys{
  show-overfull/.is if=mat@showoverfull,
  % valeur initiale
  show-overfull=false,
}

% la famille de polices pour les titres
\mapo@keys{
  default-family/.is choice,
  default-family/serif/.code={\def\mapo@default@font@family{\rmdefault}},
  default-family/sans-serif/.code={\def\mapo@default@font@family{\sfdefault}},
  % initial values
  default-family=sans-serif,
}

% traitement des options
\ProcessPgfOptions{\mapo@keys@prefix}



\LoadClass{article}
\setlength\overfullrule{\ifbool{mat@showoverfull}{1em}{0pt}}
\pagestyle{empty}

\RequirePackage[T1]{fontenc}

\RequirePackage[\mapo@languages,main=\mapo@mainlanguage]{babel}

\AtBeginDocument{\RequirePackage[autostyle=true]{csquotes}}
\usepackage[babel=true]{microtype}

\mapo@keys{font-family@apply}
\renewcommand{\familydefault}{\mapo@default@font@family}


\RequirePackage{graphicx}
\RequirePackage{xcolor}

\definecolor{mines-albi orange}{RGB}{239,125,0} % orange nouveau logo
\definecolor{mines-albi blue}{RGB}{0,20,137} % definition Pantone
\definecolor{mines-albi blue 2}{RGB}{12,35,64} % definition Pantone
\definecolor{mines-albi gray}{RGB}{92,102,112}
\definecolor{mines-albi silver}{RGB}{217,225,226}
\definecolor{mines-albi black}{RGB}{60,60,60}
\definecolor{mines-albi yellow}{RGB}{250,184,30}
\definecolor{mines-albi green1}{RGB}{7,100,65}
\definecolor{mines-albi green2}{RGB}{105,163,20}
\colorlet{mines-albi green}{mines-albi green1!60!mines-albi green2}
\definecolor{mines-albi red}{RGB}{200,50,50}
\definecolor{mines-albi cyan}{RGB}{0,184,222}


% \ifmapo@landscape
% \typeout{paper:\mapo@paper (landscape), font base size:\mapo@basesize}
% \else
% \typeout{paper:\mapo@paper (portrait), font base size:\mapo@basesize}
% \fi

% font sizes (from \mapo@basesize)
\def\mapo@fontsize#1{\noexpand\fontsize{#1}{\fpeval{#1*1.17}}}
\def\mapo@selectfont#1{\mapo@fontsize{#1}\noexpand\selectfont}

\edef\HUGE{\mapo@selectfont{\fpeval{\mapo@basesize*34/10}}}%
\edef\Huge{\mapo@selectfont{\fpeval{\mapo@basesize*24.88/10}}}%
\edef\huge{\mapo@selectfont{\fpeval{\mapo@basesize*20.74/10}}}%
\edef\LARGE{\mapo@selectfont{\fpeval{\mapo@basesize*17.28/10}}}%
\edef\Large{\mapo@selectfont{\fpeval{\mapo@basesize*14.4/10}}}%
\edef\large{\mapo@selectfont{\fpeval{\mapo@basesize*12/10}}}%
\edef\normalsize{\mapo@selectfont{\fpeval{\mapo@basesize*10/10}}}%
\edef\small{\mapo@selectfont{\fpeval{\mapo@basesize*9/10}}}%
\edef\footnotesize{\mapo@selectfont{\fpeval{\mapo@basesize*8/10}}}%
\edef\scriptsize{\mapo@selectfont{\fpeval{\mapo@basesize*7/10}}}%
\edef\tiny{\mapo@selectfont{\fpeval{\mapo@basesize*6/10}}}%
\edef\Tiny{\mapo@selectfont{\fpeval{\mapo@basesize*5/10}}}%
\edef\TINY{\mapo@selectfont{\fpeval{\mapo@basesize*4/10}}}%

\ifmapo@landscape
\RequirePackage[paper=\mapo@paper,landscape]{geometry}
\else
\RequirePackage[paper=\mapo@paper]{geometry}
\fi
\newlength{\mapo@unit}
\ifmapo@landscape
\setlength{\mapo@unit}{\dimexpr\paperheight/20\relax}
\else
\setlength{\mapo@unit}{\dimexpr\paperwidth/20\relax}
\fi
%\geometry{margin=.5\mapo@unit}

\RequirePackage{tikz}
\usetikzlibrary{calc,backgrounds,fit,babel}

% definition du handler .pgfmathsetmacro
\pgfkeys{/handlers/.pgfmathsetmacro/.code={\pgfkeysalso{\pgfkeyscurrentpath/.code={%
        \pgfmathsetmacro#1{##1}%
        % \typeout{\string#1:#1}%
      }}}}

\tikzset{%
  % un style pour une tikzpicture globalement positionnée sur la page
  maposter global picture/.style={%
    overlay,remember picture,shift={(current page.south west)}%
  },%
  % pour imposer une hauteur et un profondeur constante du texte contenu
  % dans un node (via \vphantom ou via \strut)
  fix node via vphantom/.style={%
    execute at begin node={\vphantom{Ég}},
    execute at end node={\vphantom{Ég}},
  },%
  fix node via strut/.style={%
    execute at begin node={\strut},
    execute at end node={\strut},
  },%
  % les styles de quelques éléments d'un maposter
  title block/.style={
    text width=\paperwidth-7\mapo@unit,text=white,align=flush right,
    fix node via vphantom,
  },
  title/.style={%
    title block,
    anchor=north east,inner sep=0,
    node font=\huge\bfseries,
    at={([shift={(-.5\mapo@unit,-.5\mapo@unit)}]current page.north east)},
    node contents={\mapo@poster@title},
    name=title,
  },%
  authors/.style={%
    title block,
    anchor=north east,inner sep=0,
    node font=\Large,
    at={($(title.south east) + (0,-.25\mapo@unit)$)},
    node contents={\mapo@poster@authors},
    name=authors,
  },%
  logo/.style={%
    anchor=north west,inner sep=0,
    at={($(current page.north west) + (.5\mapo@unit,-.5\mapo@unit)$)},
    node contents={\includegraphics[width=4\mapo@unit]{logo-imt-mines-albi-couleur-crop}},
    name=logo,
  },%
  header bottom/.style={
    at={([yshift=-.25\mapo@unit]authors.south -| current page.south)},
    name=header bottom,
  },
}

\def\mapo@global@pgfmathsetmacro#1#2{%
  \pgfmathsetmacro\mapo@temp{#2}%
  \expandafter\gdef\expandafter#1\expandafter{\mapo@temp}%
  % \typeout{\string#1:\mapo@temp}
}

\def\ptypeout#1{%
  % \typeout{#1: \x{#1}, \y{#1}}
}

\def\mapo@maketitleandmargins{%
  \begin{tikzpicture}[maposter global picture]
    % logo
    \node[logo];
    % title
    \node[title];
    % point de séparation blanc/orange du bord haut
    \coordinate (top sep) at ($(title.north west |- current page.north)!1!90:(title.north west)$);
    % point de séparation blanc/gris du bord gauche
    \coordinate (left sep) at ($(current page.north west)!1!-90:(top sep)$);
    % point de jonction ideal
    \coordinate (ideal jonction) at ($(top sep)!.5!(left sep)$);
    % authors
    \node[authors];
    % point central du bas de l'entête
    \coordinate[header bottom];
    % le node 'header' (l'entête: titre, auteurs et logo)
    \node[inner sep=0,line width=0pt,
    fit=(current page.north east)(current page.north west)(header bottom)(ideal jonction),
    name=header]{};
    % le point de jonction entre l'orange et le gris
    \coordinate (jonction) at ($(top sep |- header.south)!1!90:(top sep)$);
    % \fill[red] (jonction) circle (2mm);
    % le node 'margin' (la marge grise, sans la partie triangulaire)
    \node[inner sep=0,line width=0pt,fit=(current page.south west)(left sep)(left sep -| ideal jonction),name=margin]{};
    % la position haut/gauche d'insertion d'une nouvelle note de marge
    \coordinate (margin note topleft)%
    at ([xshift=.5\mapo@unit]margin.north west);
    % la position bas/gauche d'insertion d'une nouvelle note de marge
    \coordinate (margin note bottomleft)%
    at ([shift={(.5\mapo@unit,.5\mapo@unit)}]margin.south west);
    % la largeur d'une note de marge
    \path let
    \p{left}=(margin.west),
    \p{right}=(margin.east),
    \n{margin width}={\x{right}-\x{left}-\mapo@unit}
    in
    \pgfextra{\mapo@global@pgfmathsetmacro\mapo@margin@note@width{\n{margin width}}};
    % le node 'content' (le contenu du poster)
    \node[inner sep=0,line width=0pt,fit=(jonction -| ideal jonction)(current page.south east),name=content]{};
    % \fill[red] (content) circle (2mm);
    % \typeout{***}
    
    \begin{scope}[on background layer]
      % le fond de couleur
      \fill[maposter background color] (current page.south west) rectangle (current page.north east);
      % le triangle blanc
      \fill[white] (top sep) -| (left sep) -- cycle;
      % le trapèze gris
      \fill[mines-albi silver] (current page.south west) -- (left sep) -- ($(left sep)!.5!(top sep)$) |-  cycle;
      % le trapèze gris
      \fill[mines-albi silver] (current page.south west) -- (left sep) -- (jonction) |-  cycle;
      % le trapèze orange
      \fill[mines-albi orange] (header.north east) -- (top sep) -- (jonction) -| cycle; 
    \end{scope}
    
    \path
    let
    \p{topleft}=(content.north west),
    \p{bottomright}=(content.south east),
    \p{page topleft}=(current page.north west),
    \p{page bottomright}=(current page.south east)
    in \pgfextra{
      %\ptypeout{topleft}
      %\ptypeout{bottomright}
      %\ptypeout{page topleft}
      %\ptypeout{page bottomright}
      \mapo@global@pgfmathsetmacro\mapo@x@pos{\x{topleft}-\x{page topleft}}
      \mapo@global@pgfmathsetmacro\mapo@y@pos{\y{topleft}-\y{page bottomright}}
      \mapo@global@pgfmathsetmacro\mapo@text@width{\x{bottomright}-\x{topleft}}
      \mapo@global@pgfmathsetmacro\mapo@text@height{\y{topleft}-\y{bottomright}}
    };
  \end{tikzpicture}%
}

% pour ajouter du contenu à partir du haut de la marge grise
\tikzset{
  maposter@margin/.style={
    text width=\mapo@margin@note@width pt,inner sep=0,
    execute at begin node=\mapo@set@parskip,
    align=flush left,
    node font=\small,
    text=margin text color,
  },
}
\NewDocumentCommand\margintopblock{O{} +m}{%
  \begin{tikzpicture}[maposter global picture]
    \node[anchor=north west,maposter@margin,#1]
    (margin note) at (margin note topleft) {#2};
    \coordinate (margin note topleft) at ([yshift=-.5\mapo@unit]margin note.south west);
  \end{tikzpicture}%
}

% pour ajouter du contenu à partir du bas de la marge grise
\NewDocumentCommand\marginbottomblock{O{} +m}{%
  \begin{tikzpicture}[maposter global picture]
    \node[anchor=south west,maposter@margin,#1]
    (margin note) at (margin note bottomleft) {#2};
    \coordinate (margin note bottomleft) at ([yshift=.5\mapo@unit]margin note.north west);
  \end{tikzpicture}%
}

\tikzset{
  debug/.style={
    fill=cyan!20,inner sep=1pt,node contents={#1},text=black,
    rotate=\n{angle},
  },
}

% l'environnement 'block' pour créer du contenu *quelconque* dans un node tikz
\mapo@keys{
  block/.is family,
  block,
  padding top/.store in=\mapo@block@padding@top,
  padding right/.store in=\mapo@block@padding@right,
  padding bottom/.store in=\mapo@block@padding@bottom,
  padding left/.store in=\mapo@block@padding@left,
  % 
  padding horizontal/.style={padding left=#1,padding right=#1},
  padding vertical/.style={padding top=#1,padding bottom=#1},
  padding/.style={padding horizontal=#1,padding vertical=#1},
  % 
  vertical align/.is choice,
  vertical align/top/.code={\def\mapo@block@vertical@align{t}},
  vertical align/center/.code={\def\mapo@block@vertical@align{c}},
  vertical align/bottom/.code={\def\mapo@block@vertical@align{b}},
  vertical align/spread/.code={\def\mapo@block@vertical@align{s}},
  % 
  horizontal align/.is choice,
  horizontal align/left/.code={\def\mapo@block@horizontal@align{\raggedright}},
  horizontal align/center/.code={\def\mapo@block@horizontal@align{\centering}},
  horizontal align/right/.code={\def\mapo@block@horizontal@align{\raggedleft}},
  horizontal align/justify/.code={\def\mapo@block@horizontal@align{\justify}},
  %
  text/.code={\colorlet{block text color}{#1}},
  % style debug (pour TikZ)
  block/.style={},
  % style utilisateur (pour TikZ)
  frame/.style={},
  % 
  true block/.style={},
  % 
  typeout padding/.code={%
    \typeout{padding: \mapo@block@padding@top, \mapo@block@padding@right, \mapo@block@padding@bottom, \mapo@block@padding@left}%
  },
  % initial values
  text=gray!75!black,
  % default values
  default/.style={padding=0pt,vertical align=spread,horizontal align=left},
}
\newbox\mapo@box
\newlength\blockwidth
\newlength\blockheight
\NewDocumentEnvironment{block}{%
  O{} % #1 (optional) is a list of key/value pairs
  m   % nom du bloc à remplir
}{%
  %\typeout{^^J--- start block '#2'}%
  \mapo@keys{block,default,#1}%
  \begin{tikzpicture}[maposter global picture]
    \path let
    \p{topleft} = (#2.north west),
    \p{wvec} = ($(#2.north east)-(#2.north west)$),
    \p{hvec} = ($(#2.south west)-(#2.north west)$),
    \n{angle} = {scalar(atan2(\y{wvec},\x{wvec}))}
    in \pgfextra {
      \mapo@global@pgfmathsetmacro\mapo@x@block{\x{topleft}+\mapo@block@padding@left}
      \mapo@global@pgfmathsetmacro\mapo@y@block{\y{topleft}-\mapo@block@padding@top}
      \mapo@global@pgfmathsetmacro\mapo@width@block{veclen(\x{wvec},\y{wvec})-\mapo@block@padding@left-\mapo@block@padding@right}
      \mapo@global@pgfmathsetmacro\mapo@height@block{veclen(\x{hvec},\y{hvec})-\mapo@block@padding@top-\mapo@block@padding@bottom}
      \mapo@global@pgfmathsetmacro\mapo@angle@block{\n{angle}}
    };
  \end{tikzpicture}
  \setlength\blockheight{\mapo@height@block pt}%
  \setlength\blockwidth{\mapo@width@block pt}%
  %\typeout{x:\mapo@x@block,y:\mapo@y@block,w:\mapo@width@block,h:\mapo@height@block}%
  \par%
  \mapo@set@parskip%
  \vfuzz=0pt%
  \color{block text color}%
  \setbox\mapo@box=\vtop\bgroup\hbox to \mapo@width@block pt\bgroup%
  \minipage[t][\mapo@height@block pt][\mapo@block@vertical@align]%
  {\mapo@width@block pt}%
  \mapo@set@parskip\mapo@block@horizontal@align%
  \@ifnextchar\par{\block@gobblepar}{}%
}{%
  \endminipage%
  \egroup\egroup%
  %\typeout{*** mapo@box(ht:\the\ht\mapo@box,dp:\the\dp\mapo@box,wd:\the\wd\mapo@box)}%
  \begin{tikzpicture}[maposter global picture]
    \node[rotate fit=\mapo@angle@block,inner sep=0,fit=(#2),line width=0,\mapo@keys@prefix/block/frame,node contents={}];
    \node[rotate fit=\mapo@angle@block,inner sep=0,fit=(#2),line width=0,\mapo@keys@prefix/block/block,node contents={}];
    \node[rotate=\mapo@angle@block,
    inner sep=0pt,line width=0pt,anchor=north west,
    text width=\mapo@width@block,
    \mapo@keys@prefix/block/true block]
    at (\mapo@x@block pt,\mapo@y@block pt)
    {\box\mapo@box};
  \end{tikzpicture}%
  %\typeout{--- end block '#2'^^J}%
}

% pour "manger" les espaces et les passages à la ligne en début de block
\NewDocumentCommand\block@gobblepar{+m}{%
  \@ifnextchar\par{\block@gobblepar}{}%
}

\NewDocumentCommand\styledblock{O{}m}{%
  \begin{block}[#1,vertical align=top,horizontal align=left]{#2}\vspace*{\blockheight}\end{block}%
}

% l'environnement 'maposter' pour créer un poster
\mapo@keys{
  mapoposter/.is family,
  mapoposter,
  %
  % les paramètres de base
  title/.store in=\mapo@poster@title,
  authors/.store in=\mapo@poster@authors,
  %
  background color/.code={\colorlet{maposter background color}{#1}},
  text color/.code={\colorlet{block text color}{#1}},
  %
  padding top/.store in=\mapo@poster@padding@top,
  padding right/.store in=\mapo@poster@padding@right,
  padding bottom/.store in=\mapo@poster@padding@bottom,
  padding left/.store in=\mapo@poster@padding@left,
  %
  % des raccourcis sous forme de styles
  padding horizontal/.style={padding left=#1,padding right=#1},
  padding vertical/.style={padding top=#1,padding bottom=#1},
  padding/.style={padding horizontal=#1,padding vertical=#1},
  % les paramètres par défaut
  default style/.style={
    padding=0pt,
    background color=white,
    text color=black,
    title=\@title,
    authors=\@author,
  },
}

\NewDocumentEnvironment{maposter}{m}
{%
  \newpage%
  % \typeout{paper: \the\paperwidth, \the\paperheight}%
  \mapo@keys{mapoposter,default style,#1}%
  %\begin{textblock*}{\paperwidth}(0pt,0pt)%
    \mapo@maketitleandmargins%
  %\end{textblock*}%
}{%
}

% la commande '\splitv' pour découper un node tikz du nord au sud
% en plusieurs sous-nodes
\mapo@keys{
  splitv/.is family,
  splitv,
  %
  top margin/.pgfmathsetmacro=\mapo@splitv@topmargin,
  middle margin/.pgfmathsetmacro=\mapo@splitv@middlemargin,
  bottom margin/.pgfmathsetmacro=\mapo@splitv@bottommargin,
  margins/.style={top margin=#1,bottom margin=#1,middle margin=#1},
  % default values
  default/.style={margins=0pt,middle margin=.5\mapo@unit},
}


\NewDocumentCommand\splitv{
  O{} % options
  m % node to split
  m % list of pairs {part's name/weight}
}{
  \mapo@keys{splitv,default,#1}
  \edef\mapo@list@of@names@weights{#3}
  % le poids total et le décompte
  \def\mapo@total@weight{0}
  \def\mapo@count{0}
  \mapo@keys{
    add to mapo@total@weight/.code args={##1/##2}{
      \pgfmathsetmacro\mapo@total@weight{\mapo@total@weight+##2}
      \pgfmathtruncatemacro\mapo@count{\mapo@count+1}
    },
    add to mapo@total@weight/.list/.expand once=\mapo@list@of@names@weights,
  }
  %
  \path let
  \p{tvec}=($(#2.north east)-(#2.north west)$),
  \p{lvec}=($(#2.south west)-(#2.north west)$),
  \n{angle}={scalar(atan2(\y{tvec},\x{tvec}))},
  % \n{height}={scalar(veclen(\x{lvec},\y{lvec}))},
  % \n{width}={scalar(veclen(\x{tvec},\y{tvec}))},
  \n{total margins}={\mapo@splitv@topmargin+(\mapo@count-1)*\mapo@splitv@middlemargin+\mapo@splitv@bottommargin},
  \n{total height}={scalar(veclen(\x{lvec},\y{lvec}) - \n{total margins})}
  in
  ($(#2.north west)!1pt*\mapo@splitv@topmargin!(#2.south west)$) coordinate (splitv pos1)
  \foreach\partname/\weight in \mapo@list@of@names@weights {
    ($(splitv pos1)!1pt*\n{total height}/\mapo@total@weight*\weight!(#2.south west)$) coordinate (splitv pos2)
    ($(splitv pos2) + (\p{tvec})$) coordinate (splitv posr)
    %
    node[rotate fit=\n{angle},anchor=north west,name=\partname,
    fit=(splitv pos1)(splitv pos2)(splitv posr),inner sep=0,line width=0pt,node contents={}]
    %
    ($(splitv pos2)!1pt*\mapo@splitv@middlemargin)!(#2.south west)$)
    coordinate (splitv pos1)
  };
}

% la commande '\splith' pour découper un node tikz d'ouest en est
% en plusieurs sous-nodes
\mapo@keys{
  splith/.is family,
  splith,
  %
  left margin/.pgfmathsetmacro=\mapo@splith@leftmargin,
  middle margin/.pgfmathsetmacro=\mapo@splith@middlemargin,
  right margin/.pgfmathsetmacro=\mapo@splith@rightmargin,
  margins/.style={left margin=#1,right margin=#1,middle margin=#1},
  % default values
  default/.style={margins=0pt,middle margin=.5\mapo@unit},
}

\NewDocumentCommand\splith{
  O{} % options
  m % node to spit
  m % list of pairs {part's name/weight}
}{
  %\typeout{*** splith: begin}%
  \mapo@keys{splith,default,#1}
  \edef\mapo@list@of@names@weights{#3}
  % le poids total et le décompte
  \def\mapo@total@weight{0}
  \def\mapo@count{0}
  \mapo@keys{
    add to mapo@total@weight/.code args={##1/##2}{
      \pgfmathsetmacro\mapo@total@weight{\mapo@total@weight+##2}
      \pgfmathtruncatemacro\mapo@count{\mapo@count+1}
    },
    add to mapo@total@weight/.list/.expand once=\mapo@list@of@names@weights,
  }
  %
  \path let
  \p{tvec}=($(#2.north east)-(#2.north west)$),
  \p{lvec}=($(#2.south west)-(#2.north west)$),
  \n{angle}={scalar(atan2(\y{tvec},\x{tvec}))},
  \n{total margins}={\mapo@splith@leftmargin+(\mapo@count-1)*\mapo@splith@middlemargin+\mapo@splith@rightmargin},
  \n{total width}={scalar(veclen(\x{tvec},\y{tvec}) - \n{total margins})}
  in
  ($(#2.north west)!1pt*\mapo@splith@leftmargin!(#2.north east)$) coordinate (splith pos1)
  %\pgfextra{\typeout{*** splith: before foreach}}
  \foreach \partname/\weight in \mapo@list@of@names@weights {
    ($(splith pos1)!{1pt*\n{total width}/\mapo@total@weight*\weight}!(#2.north east)$) coordinate (splith pos2)
    ($(splith pos2) + (\p{lvec})$) coordinate (splith posb)
    % 
    node[rotate fit=\n{angle},anchor=north west,name=\partname,
    fit=(splith pos1)(splith pos2)(splith posb),inner sep=0,line width=0pt,node contents={}]
    %
    ($(splith pos2)!1pt*\mapo@splith@middlemargin!(#2.north east)$)
    coordinate (splith pos1)
  };
  %\typeout{*** splith: end}%
}

\NewDocumentCommand\fusion{mm}{% #1: list of nodes, fusion node
  \def\mapo@list@of@nodes{}
  \mapo@keys{
    append to mapo@list@of@nodes/.code={\edef\mapo@list@of@nodes{\mapo@list@of@nodes(##1)}},
    append to mapo@list@of@nodes/.list={#1},
  }
  \node[name=#2,inner sep=0,line width=0pt,fit=\mapo@list@of@nodes]{};
}

% les commandes pour créer du contenu:
%
% \blockitem (pour un item de liste)
%
% \blocktitle (pour un titre)
%
% \margintitle (pour un titre dans la marge)
%
% \blockparagraph (pour un paragraphe avec titre)

\colorlet{item color}{mines-albi cyan}
\colorlet{block paragraph color}{mines-albi cyan}
\colorlet{poster title text color}{mines-albi orange}
\colorlet{margin text color}{black}
\colorlet{margin title text color}{black}

\NewDocumentCommand\blockitem{m+m}{%
  \def\blockitemsep{\tikz{\fill[item color] (0,0) -- +(1.5ex,.6ex) -- +(0,1.2ex) -- cycle;}}%
  \pgfmathsetmacro\trilen{2.25ex}%
  \pgfmathsetmacro\minipagelen{\linewidth - \trilen}%
  %\typeout{trilen:\trilen,minipagelen:\minipagelen}%
  \setbox\mapo@box=\vbox{%
    \textcolor{item color}{\makebox[\trilen pt][l]{\blockitemsep}}%
    \begin{minipage}[t]{\minipagelen pt}%
      \maposetparskip\raggedright%
      \textcolor{item color}{\textbf{\vphantom{Ég}#1}}#2%
    \end{minipage}%
  }%
  % \typeout{*** mapo@box(ht:\the\ht\mapo@box,dp:\the\dp\mapo@box,wd:\the\wd\mapo@box}%
  \raisebox{\depth}[\totalheight][0pt]{\box\mapo@box}\par
}

\NewDocumentCommand\blocktitle{m}{%
  \textcolor{poster title text color}{\Large\textbf{\vphantom{Ég}#1}}\par
}

\NewDocumentCommand\margintitle{m}{%
  {\textcolor{margin title text color}{#1}\\
    \rule[.5\baselineskip]{\linewidth}{1pt}\\}%
}

\renewcommand\paragraph{%
  \@startsection%
  {paragraph}% name                
  {4}% level               
  {\z@}% indentation         
  {1ex plus 10em}%  beforeskip
  {-.5em plus 1em}% afterskip
  {\bfseries}% style
}
\NewDocumentCommand\blockparagraph{m}{\paragraph{\textcolor{block paragraph color}{#1}}}

%\NewDocumentCommand\ressort{}{\vspace*{0mm plus \paperheight}}
\NewDocumentCommand\ressort{}{\null\vfil\null}


\let\mapounit=\mapo@unit

\def\mapo@set@parskip{%
  \setlength\parindent{0pt}%
  \setlength\parskip%
  % {.5\baselineskip plus .2\baselineskip minus .1\baselineskip}%
  {1\baselineskip plus 100\baselineskip minus .9\baselineskip}%
}

\let\maposetparskip\mapo@set@parskip

